Module process

Module process 

Per-process data such as command line arguments and environment variables.

Structs

SpawnArgs
SpawnArgsRt
SpawnResult

Constants

MAX_ENV_KEY_LEN
An arbitrarily defined maximum lenth of an environment variable key.
MAX_ENV_VAL_LEN
An arbitrarily defined maximum lenth of an environment variable value.
STDIO_INHERIT
STDIO_IS_TERMINAL_ENV_KEY
If this ENV var is present, and its value is “true” or “TRUE”, the stdio of the process will return true on is_terminal(), otherwise false.
STDIO_MAKE_PIPE
STDIO_NULL

Functions

args
Get all commandline args for the current process.
current_exe
env
Get all environment variables for the current process.
exit
getenv
Get a specific environment variable, if set.
kill
setenv
Set an environment variable.
spawn
try_wait
unsetenv
Unset an environment variable.
wait