Struct SpawnArgsRt
Source #[repr(C)]
pub struct SpawnArgsRt {
pub prog_name_addr: u64,
pub prog_name_size: u64,
pub args: u64,
pub env: u64,
pub stdin: RtFd,
pub stdout: RtFd,
pub stderr: RtFd,
pub _reserved: i32,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.