pub struct UtcDateTime {
pub year: u32,
pub month: u8,
pub day: u8,
pub hour: u8,
pub minute: u8,
pub second: u8,
pub nanosecond: u32,
}Fields
year: u32month: u8day: u8hour: u8minute: u8second: u8nanosecond: u32Implementations
Sourceimpl UtcDateTime
impl UtcDateTime
pub fn now() -> Self
Sourcepub unsafe fn from_instant(ts: Instant) -> Self
pub unsafe fn from_instant(ts: Instant) -> Self
Converts a value of Instant into UtcDateTime.
Safety
If the host adjust its date/time while the guest is running, the result may be way off, so should only be used in non-critical situations such as tests.
pub fn from_unix_nanos(nanos: u128) -> Self