Per-process data such as command line arguments and environment variables.
Structs
Constants
- MAX_
ENV_ KEY_ LEN - An arbitrarily defined maximum lenth of an environment variable key.
- MAX_
ENV_ VAL_ LEN - An arbitrarily defined maximum lenth of an environment variable value.
- STDIO_
INHERIT - STDIO_
IS_ TERMINAL_ ENV_ KEY - If this ENV var is present, and its value is “true” or “TRUE”, the stdio of the process will return true on is_terminal(), otherwise false.
- STDIO_
MAKE_ PIPE - STDIO_
NULL