Per-process data such as command line arguments and environment variables.
Structs
Constants
- An arbitrarily defined maximum lenth of an environment variable key.
- An arbitrarily defined maximum lenth of an environment variable value.
Functions
- Get all commandline args for the current process.
- Get all environment variables for the current process.
- Get a specific environment variable, if set.
- Set an environment variable.
- Unset an environment variable.